Provided with a study ID and a lead variant ID, this function returns a
data frame consisting of all the associated credible set tag variants
with the corresponding statistical data.
Usage
gwasCredibleSet(study_id, variant_id)
Value
Returns a data frame of results from the credible set of variants for a specific lead variant with the following columns:
tagVariant.id: Data frame. A table of IDs of the tag variant.
tagVariant.rsId: Character vector. rsID of the tag variant.
beta: Numeric. Beta value.
postProb: Numeric. Posterior probability.
pval: Numeric. P-value.
se: Numeric. Standard error.
MultisignalMethod: Character vector. Multisignal method.
logABF: Numeric. Logarithm of approximate Bayes factor.
is95: Logical. Indicates if the variant has a 95
is99: Logical. Indicates if the variant has a 99
Arguments
study_id
Character: Study ID(s) generated by Open Targets (e.g GCST90002357).
variant_id
Character: generated ID for variants by Open Targets (e.g. 1_154119580_C_A) or rsId (rs2494663).
if (FALSE) {
result <- gwasCredibleSet(study_id="GCST90002357",
variant_id="1_154119580_C_A")
result <- gwasCredibleSet(study_id="GCST90002357", variant_id="rs2494663")
}