knownDrugsChemblQuery: Retrieve indications and clinical report data for a specified...

View source: R/knownDrugsChemblQuery.R

knownDrugsChemblQueryR Documentation

Retrieve indications and clinical report data for a specified drug.

Description

This function queries the Open Targets GraphQL API to retrieve indications and clinical report data for a specified drug.

Usage

knownDrugsChemblQuery(chemblId)

Arguments

chemblId

Character: ChEMBL ID of the target drug (e.g., "CHEMBL1016").

Value

Returns a tibble containing indications data for the specified drug.

Examples

## Not run: 
result <- knownDrugsChemblQuery(chemblId = "CHEMBL1016")

## End(Not run)

otargen documentation built on May 23, 2026, 5:11 p.m.