Retrieve drug and clinical candidate data for a specified gene.
Source:R/knownDrugsGeneQuery.R
knownDrugsGeneQuery.RdThis function queries the Open Targets GraphQL API to retrieve drug and clinical candidate data for a specified gene.

R/knownDrugsGeneQuery.R
knownDrugsGeneQuery.RdThis function queries the Open Targets GraphQL API to retrieve drug and clinical candidate data for a specified gene.