knownDrugsGeneQuery: Retrieve drug and clinical candidate data for a specified...

View source: R/knownDrugsGeneQuery.R

knownDrugsGeneQueryR Documentation

Retrieve drug and clinical candidate data for a specified gene.

Description

This function queries the Open Targets GraphQL API to retrieve drug and clinical candidate data for a specified gene.

Usage

knownDrugsGeneQuery(ensgId)

Arguments

ensgId

Character: ENSEMBL ID of the target gene (e.g., ENSG00000169174).

Value

Returns a data frame containing drug and clinical candidate data for the specified gene.

Examples

## Not run: 
result <- knownDrugsGeneQuery(ensgId = "ENSG00000169174")

## End(Not run)

otargen documentation built on May 23, 2026, 5:11 p.m.