View source: R/knownDrugsGeneQuery.R
| knownDrugsGeneQuery | R Documentation |
This function queries the Open Targets GraphQL API to retrieve drug and clinical candidate data for a specified gene.
knownDrugsGeneQuery(ensgId)
ensgId |
Character: ENSEMBL ID of the target gene (e.g., ENSG00000169174). |
Returns a data frame containing drug and clinical candidate data for the specified gene.
## Not run:
result <- knownDrugsGeneQuery(ensgId = "ENSG00000169174")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.