Draws a circular network layout of molecular interaction partners with edge thickness proportional to the interaction confidence score.
Arguments
- df
A tibble returned by
interactionsQuery.- top_n
Integer: number of top interactions to display (default: 20).
Examples
if (FALSE) { # \dontrun{
int <- interactionsQuery(ensgId = "ENSG00000141510",
sourceDatabase = "intact", size = 25)
plot_interactions(int)
} # }