powered by
This function queries the Open Targets GraphQL API to retrieve UniProt literature evidence data for a specified gene and disease.
uniprotLiteratureQuery(ensemblId, efoId, size = 3500)
Returns a tibble containing UniProt literature evidence data for the specified gene and disease.
Character: ENSEMBL ID of the target gene (e.g., "ENSG00000130203").
Character: EFO ID of the target disease (e.g., "MONDO_0004975").
Integer: Number of records to retrieve (default: 3500).
if (FALSE) { result <- uniprotLiteratureQuery(ensemblId = "ENSG00000130203", efoId = "MONDO_0004975", size = 3500) }
Run the code above in your browser using DataLab